# xchainpy2-thornode
Thornode REST API.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 3.3.0
- Package version: 3.3.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import xchainpy2_thornode 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import xchainpy2_thornode
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import xchainpy2_thornode
from xchainpy2_thornode.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = xchainpy2_thornode.AuthApi(xchainpy2_thornode.ApiClient(configuration))
address = 'address_example' # str | 
height = 789 # int | optional block height, defaults to current tip (optional)

try:
    api_response = api_instance.account(address, height=height)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AuthApi->account: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to */*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthApi* | [**account**](docs/AuthApi.md#account) | **GET** /auth/accounts/{address} | 
*BankApi* | [**balances**](docs/BankApi.md#balances) | **GET** /bank/balances/{address} | 
*BlockApi* | [**block**](docs/BlockApi.md#block) | **GET** /thorchain/block | 
*BorrowersApi* | [**borrower**](docs/BorrowersApi.md#borrower) | **GET** /thorchain/pool/{asset}/borrower/{address} | 
*BorrowersApi* | [**borrowers**](docs/BorrowersApi.md#borrowers) | **GET** /thorchain/pool/{asset}/borrowers | 
*CloutApi* | [**swapper_clout**](docs/CloutApi.md#swapper_clout) | **GET** /thorchain/clout/swap/{address} | 
*ExportApi* | [**export**](docs/ExportApi.md#export) | **GET** /thorchain/export | 
*HealthApi* | [**ping**](docs/HealthApi.md#ping) | **GET** /thorchain/ping | 
*InvariantsApi* | [**invariant**](docs/InvariantsApi.md#invariant) | **GET** /thorchain/invariant/{invariant} | 
*InvariantsApi* | [**invariants**](docs/InvariantsApi.md#invariants) | **GET** /thorchain/invariants | 
*LiquidityProvidersApi* | [**liquidity_provider**](docs/LiquidityProvidersApi.md#liquidity_provider) | **GET** /thorchain/pool/{asset}/liquidity_provider/{address} | 
*LiquidityProvidersApi* | [**liquidity_providers**](docs/LiquidityProvidersApi.md#liquidity_providers) | **GET** /thorchain/pool/{asset}/liquidity_providers | 
*MimirApi* | [**mimir**](docs/MimirApi.md#mimir) | **GET** /thorchain/mimir | 
*MimirApi* | [**mimir_admin**](docs/MimirApi.md#mimir_admin) | **GET** /thorchain/mimir/admin | 
*MimirApi* | [**mimir_key**](docs/MimirApi.md#mimir_key) | **GET** /thorchain/mimir/key/{key} | 
*MimirApi* | [**mimir_node**](docs/MimirApi.md#mimir_node) | **GET** /thorchain/mimir/node/{address} | 
*MimirApi* | [**mimir_nodes**](docs/MimirApi.md#mimir_nodes) | **GET** /thorchain/mimir/nodes_all | 
*NetworkApi* | [**ban**](docs/NetworkApi.md#ban) | **GET** /thorchain/ban/{address} | 
*NetworkApi* | [**constants**](docs/NetworkApi.md#constants) | **GET** /thorchain/constants | 
*NetworkApi* | [**inbound_addresses**](docs/NetworkApi.md#inbound_addresses) | **GET** /thorchain/inbound_addresses | 
*NetworkApi* | [**lastblock**](docs/NetworkApi.md#lastblock) | **GET** /thorchain/lastblock | 
*NetworkApi* | [**lastblock_chain**](docs/NetworkApi.md#lastblock_chain) | **GET** /thorchain/lastblock/{chain} | 
*NetworkApi* | [**network**](docs/NetworkApi.md#network) | **GET** /thorchain/network | 
*NetworkApi* | [**outbound_fee_asset**](docs/NetworkApi.md#outbound_fee_asset) | **GET** /thorchain/outbound_fee/{asset} | 
*NetworkApi* | [**outbound_fees**](docs/NetworkApi.md#outbound_fees) | **GET** /thorchain/outbound_fees | 
*NetworkApi* | [**ragnarok**](docs/NetworkApi.md#ragnarok) | **GET** /thorchain/ragnarok | 
*NetworkApi* | [**upgrade_proposal**](docs/NetworkApi.md#upgrade_proposal) | **GET** /thorchain/upgrade_proposal/{name} | 
*NetworkApi* | [**upgrade_proposals**](docs/NetworkApi.md#upgrade_proposals) | **GET** /thorchain/upgrade_proposals | 
*NetworkApi* | [**upgrade_votes**](docs/NetworkApi.md#upgrade_votes) | **GET** /thorchain/upgrade_votes/{name} | 
*NetworkApi* | [**version**](docs/NetworkApi.md#version) | **GET** /thorchain/version | 
*NodesApi* | [**node**](docs/NodesApi.md#node) | **GET** /thorchain/node/{address} | 
*NodesApi* | [**nodes**](docs/NodesApi.md#nodes) | **GET** /thorchain/nodes | 
*PoolSlipApi* | [**poolslip**](docs/PoolSlipApi.md#poolslip) | **GET** /thorchain/slip/{asset} | 
*PoolSlipApi* | [**poolslips**](docs/PoolSlipApi.md#poolslips) | **GET** /thorchain/slips | 
*PoolsApi* | [**dpool**](docs/PoolsApi.md#dpool) | **GET** /thorchain/dpool/{asset} | 
*PoolsApi* | [**dpools**](docs/PoolsApi.md#dpools) | **GET** /thorchain/dpools | 
*PoolsApi* | [**pool**](docs/PoolsApi.md#pool) | **GET** /thorchain/pool/{asset} | 
*PoolsApi* | [**pools**](docs/PoolsApi.md#pools) | **GET** /thorchain/pools | 
*QueueApi* | [**queue**](docs/QueueApi.md#queue) | **GET** /thorchain/queue | 
*QueueApi* | [**queue_outbound**](docs/QueueApi.md#queue_outbound) | **GET** /thorchain/queue/outbound | 
*QueueApi* | [**queue_scheduled**](docs/QueueApi.md#queue_scheduled) | **GET** /thorchain/queue/scheduled | 
*QueueApi* | [**queue_swap**](docs/QueueApi.md#queue_swap) | **GET** /thorchain/queue/swap | 
*QuoteApi* | [**quoteloanclose**](docs/QuoteApi.md#quoteloanclose) | **GET** /thorchain/quote/loan/close | 
*QuoteApi* | [**quoteloanopen**](docs/QuoteApi.md#quoteloanopen) | **GET** /thorchain/quote/loan/open | 
*QuoteApi* | [**quotesaverdeposit**](docs/QuoteApi.md#quotesaverdeposit) | **GET** /thorchain/quote/saver/deposit | 
*QuoteApi* | [**quotesaverwithdraw**](docs/QuoteApi.md#quotesaverwithdraw) | **GET** /thorchain/quote/saver/withdraw | 
*QuoteApi* | [**quoteswap**](docs/QuoteApi.md#quoteswap) | **GET** /thorchain/quote/swap | 
*RUNEPoolApi* | [**rune_pool**](docs/RUNEPoolApi.md#rune_pool) | **GET** /thorchain/runepool | 
*RUNEPoolApi* | [**rune_provider**](docs/RUNEPoolApi.md#rune_provider) | **GET** /thorchain/rune_provider/{address} | 
*RUNEPoolApi* | [**rune_providers**](docs/RUNEPoolApi.md#rune_providers) | **GET** /thorchain/rune_providers | 
*SaversApi* | [**saver**](docs/SaversApi.md#saver) | **GET** /thorchain/pool/{asset}/saver/{address} | 
*SaversApi* | [**savers**](docs/SaversApi.md#savers) | **GET** /thorchain/pool/{asset}/savers | 
*SecuredAssetApi* | [**secured_asset**](docs/SecuredAssetApi.md#secured_asset) | **GET** /thorchain/securedasset/{asset} | 
*SecuredAssetsApi* | [**secured_assets**](docs/SecuredAssetsApi.md#secured_assets) | **GET** /thorchain/securedassets | 
*StreamingSwapApi* | [**stream_swap**](docs/StreamingSwapApi.md#stream_swap) | **GET** /thorchain/swap/streaming/{hash} | 
*StreamingSwapApi* | [**stream_swaps**](docs/StreamingSwapApi.md#stream_swaps) | **GET** /thorchain/swaps/streaming | 
*TSSApi* | [**keygen_pubkey**](docs/TSSApi.md#keygen_pubkey) | **GET** /thorchain/keygen/{height}/{pubkey} | 
*TSSApi* | [**keysign**](docs/TSSApi.md#keysign) | **GET** /thorchain/keysign/{height} | 
*TSSApi* | [**keysign_pubkey**](docs/TSSApi.md#keysign_pubkey) | **GET** /thorchain/keysign/{height}/{pubkey} | 
*TSSApi* | [**metrics**](docs/TSSApi.md#metrics) | **GET** /thorchain/metrics | 
*TSSApi* | [**metrics_keygen**](docs/TSSApi.md#metrics_keygen) | **GET** /thorchain/metric/keygen/{pubkey} | 
*ThornamesApi* | [**thorname**](docs/ThornamesApi.md#thorname) | **GET** /thorchain/thorname/{name} | 
*TradeAccountApi* | [**trade_account**](docs/TradeAccountApi.md#trade_account) | **GET** /thorchain/trade/account/{address} | 
*TradeAccountsApi* | [**trade_accounts**](docs/TradeAccountsApi.md#trade_accounts) | **GET** /thorchain/trade/accounts/{asset} | 
*TradeUnitApi* | [**trade_unit**](docs/TradeUnitApi.md#trade_unit) | **GET** /thorchain/trade/unit/{asset} | 
*TradeUnitsApi* | [**trade_units**](docs/TradeUnitsApi.md#trade_units) | **GET** /thorchain/trade/units | 
*TransactionsApi* | [**tx**](docs/TransactionsApi.md#tx) | **GET** /thorchain/tx/{hash} | 
*TransactionsApi* | [**tx_signers**](docs/TransactionsApi.md#tx_signers) | **GET** /thorchain/tx/details/{hash} | 
*TransactionsApi* | [**tx_signers_old**](docs/TransactionsApi.md#tx_signers_old) | **GET** /thorchain/tx/{hash}/signers | 
*TransactionsApi* | [**tx_stages**](docs/TransactionsApi.md#tx_stages) | **GET** /thorchain/tx/stages/{hash} | 
*TransactionsApi* | [**tx_status**](docs/TransactionsApi.md#tx_status) | **GET** /thorchain/tx/status/{hash} | 
*VaultsApi* | [**asgard**](docs/VaultsApi.md#asgard) | **GET** /thorchain/vaults/asgard | 
*VaultsApi* | [**vault**](docs/VaultsApi.md#vault) | **GET** /thorchain/vault/{pubkey} | 
*VaultsApi* | [**vault_pubkeys**](docs/VaultsApi.md#vault_pubkeys) | **GET** /thorchain/vaults/pubkeys | 
*VaultsApi* | [**yggdrasil**](docs/VaultsApi.md#yggdrasil) | **GET** /thorchain/vaults/yggdrasil | 

## Documentation For Models

 - [Account](docs/Account.md)
 - [AccountResponse](docs/AccountResponse.md)
 - [AccountResponseResult](docs/AccountResponseResult.md)
 - [Amount](docs/Amount.md)
 - [BalancesResponse](docs/BalancesResponse.md)
 - [BanResponse](docs/BanResponse.md)
 - [BaseQuoteResponse](docs/BaseQuoteResponse.md)
 - [BlockResponse](docs/BlockResponse.md)
 - [BlockResponseHeader](docs/BlockResponseHeader.md)
 - [BlockResponseHeaderVersion](docs/BlockResponseHeaderVersion.md)
 - [BlockResponseId](docs/BlockResponseId.md)
 - [BlockResponseIdParts](docs/BlockResponseIdParts.md)
 - [BlockTx](docs/BlockTx.md)
 - [BlockTxResult](docs/BlockTxResult.md)
 - [Borrower](docs/Borrower.md)
 - [BorrowerResponse](docs/BorrowerResponse.md)
 - [BorrowersResponse](docs/BorrowersResponse.md)
 - [ChainHeight](docs/ChainHeight.md)
 - [Coin](docs/Coin.md)
 - [ConstantsResponse](docs/ConstantsResponse.md)
 - [DerivedPool](docs/DerivedPool.md)
 - [DerivedPoolResponse](docs/DerivedPoolResponse.md)
 - [DerivedPoolsResponse](docs/DerivedPoolsResponse.md)
 - [ExportResponse](docs/ExportResponse.md)
 - [InboundAddress](docs/InboundAddress.md)
 - [InboundAddressesResponse](docs/InboundAddressesResponse.md)
 - [InboundConfirmationCountedStage](docs/InboundConfirmationCountedStage.md)
 - [InboundFinalisedStage](docs/InboundFinalisedStage.md)
 - [InboundObservedStage](docs/InboundObservedStage.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InvariantResponse](docs/InvariantResponse.md)
 - [InvariantsResponse](docs/InvariantsResponse.md)
 - [Keygen](docs/Keygen.md)
 - [KeygenBlock](docs/KeygenBlock.md)
 - [KeygenMetric](docs/KeygenMetric.md)
 - [KeygenMetricsResponse](docs/KeygenMetricsResponse.md)
 - [KeygenResponse](docs/KeygenResponse.md)
 - [KeysignInfo](docs/KeysignInfo.md)
 - [KeysignMetrics](docs/KeysignMetrics.md)
 - [KeysignResponse](docs/KeysignResponse.md)
 - [LastBlock](docs/LastBlock.md)
 - [LastBlockResponse](docs/LastBlockResponse.md)
 - [LiquidityProvider](docs/LiquidityProvider.md)
 - [LiquidityProviderResponse](docs/LiquidityProviderResponse.md)
 - [LiquidityProviderSummary](docs/LiquidityProviderSummary.md)
 - [LiquidityProvidersResponse](docs/LiquidityProvidersResponse.md)
 - [MetricsResponse](docs/MetricsResponse.md)
 - [MimirNodesResponse](docs/MimirNodesResponse.md)
 - [MimirResponse](docs/MimirResponse.md)
 - [MimirVote](docs/MimirVote.md)
 - [MsgSwap](docs/MsgSwap.md)
 - [NetworkResponse](docs/NetworkResponse.md)
 - [Node](docs/Node.md)
 - [NodeBondProvider](docs/NodeBondProvider.md)
 - [NodeBondProviders](docs/NodeBondProviders.md)
 - [NodeJail](docs/NodeJail.md)
 - [NodeKeygenMetric](docs/NodeKeygenMetric.md)
 - [NodePreflightStatus](docs/NodePreflightStatus.md)
 - [NodePubKeySet](docs/NodePubKeySet.md)
 - [NodeResponse](docs/NodeResponse.md)
 - [NodesResponse](docs/NodesResponse.md)
 - [ObservedTx](docs/ObservedTx.md)
 - [OutboundDelayStage](docs/OutboundDelayStage.md)
 - [OutboundFee](docs/OutboundFee.md)
 - [OutboundFeesResponse](docs/OutboundFeesResponse.md)
 - [OutboundResponse](docs/OutboundResponse.md)
 - [OutboundSignedStage](docs/OutboundSignedStage.md)
 - [POL](docs/POL.md)
 - [Ping](docs/Ping.md)
 - [PlannedOutTx](docs/PlannedOutTx.md)
 - [Pool](docs/Pool.md)
 - [PoolResponse](docs/PoolResponse.md)
 - [PoolSlipResponse](docs/PoolSlipResponse.md)
 - [PoolsResponse](docs/PoolsResponse.md)
 - [QueueResponse](docs/QueueResponse.md)
 - [QuoteFees](docs/QuoteFees.md)
 - [QuoteLoanCloseResponse](docs/QuoteLoanCloseResponse.md)
 - [QuoteLoanOpenResponse](docs/QuoteLoanOpenResponse.md)
 - [QuoteSaverDepositResponse](docs/QuoteSaverDepositResponse.md)
 - [QuoteSaverWithdrawResponse](docs/QuoteSaverWithdrawResponse.md)
 - [QuoteSwapResponse](docs/QuoteSwapResponse.md)
 - [RUNEPoolResponse](docs/RUNEPoolResponse.md)
 - [RUNEPoolResponseProviders](docs/RUNEPoolResponseProviders.md)
 - [RUNEPoolResponseReserve](docs/RUNEPoolResponseReserve.md)
 - [RUNEProvider](docs/RUNEProvider.md)
 - [RUNEProviderResponse](docs/RUNEProviderResponse.md)
 - [RUNEProvidersResponse](docs/RUNEProvidersResponse.md)
 - [Saver](docs/Saver.md)
 - [SaverResponse](docs/SaverResponse.md)
 - [SaversResponse](docs/SaversResponse.md)
 - [ScheduledResponse](docs/ScheduledResponse.md)
 - [SecuredAssetResponse](docs/SecuredAssetResponse.md)
 - [SecuredAssetsResponse](docs/SecuredAssetsResponse.md)
 - [StreamingStatus](docs/StreamingStatus.md)
 - [StreamingSwap](docs/StreamingSwap.md)
 - [StreamingSwapResponse](docs/StreamingSwapResponse.md)
 - [StreamingSwapsResponse](docs/StreamingSwapsResponse.md)
 - [SwapFinalisedStage](docs/SwapFinalisedStage.md)
 - [SwapQueueResponse](docs/SwapQueueResponse.md)
 - [SwapStatus](docs/SwapStatus.md)
 - [SwapperCloutResponse](docs/SwapperCloutResponse.md)
 - [Thorname](docs/Thorname.md)
 - [ThornameAlias](docs/ThornameAlias.md)
 - [ThornameResponse](docs/ThornameResponse.md)
 - [TradeAccountResponse](docs/TradeAccountResponse.md)
 - [TradeAccountsResponse](docs/TradeAccountsResponse.md)
 - [TradeUnitResponse](docs/TradeUnitResponse.md)
 - [TradeUnitsResponse](docs/TradeUnitsResponse.md)
 - [TssKeysignMetric](docs/TssKeysignMetric.md)
 - [TssMetric](docs/TssMetric.md)
 - [Tx](docs/Tx.md)
 - [TxDetailsResponse](docs/TxDetailsResponse.md)
 - [TxOutItem](docs/TxOutItem.md)
 - [TxResponse](docs/TxResponse.md)
 - [TxSignersResponse](docs/TxSignersResponse.md)
 - [TxStagesResponse](docs/TxStagesResponse.md)
 - [TxStatusResponse](docs/TxStatusResponse.md)
 - [UpgradeProposal](docs/UpgradeProposal.md)
 - [UpgradeProposalResponse](docs/UpgradeProposalResponse.md)
 - [UpgradeProposalsResponse](docs/UpgradeProposalsResponse.md)
 - [UpgradeVote](docs/UpgradeVote.md)
 - [UpgradeVotesResponse](docs/UpgradeVotesResponse.md)
 - [Vault](docs/Vault.md)
 - [VaultAddress](docs/VaultAddress.md)
 - [VaultInfo](docs/VaultInfo.md)
 - [VaultPubkeysResponse](docs/VaultPubkeysResponse.md)
 - [VaultResponse](docs/VaultResponse.md)
 - [VaultRouter](docs/VaultRouter.md)
 - [VaultsResponse](docs/VaultsResponse.md)
 - [VersionResponse](docs/VersionResponse.md)
 - [YggdrasilVault](docs/YggdrasilVault.md)
 - [YggdrasilVaultsResponse](docs/YggdrasilVaultsResponse.md)

## Documentation For Authorization

 All endpoints do not require authorization.


## Author

devs@thorchain.org
